# Google AI Studio

A collection of AI tools built on Google Vertex AI APIs.

Current available features:

* a simple chat bot built on Google Gemini Pro

plan: vision and other features

It is part of integrated tools, developed in our [LetMeDoIt AI project](https://github.com/eliranwong/letmedoit).

# Install

> pip install --upgrade googleaistudio

# Google API Setup

Save a copy of your API key JSON file as "\~/credentials_googleaistudio.json", where "\~" denotes your home directory.

Read https://github.com/eliranwong/letmedoit/wiki/Google-API-Setup for setting up Google API.

# Usage

Run in terminal:

> geminipro

# Documentation for Developers

https://cloud.google.com/vertex-ai/docs/generative-ai/learn/overview

https://cloud.google.com/vertex-ai/docs/generative-ai/learn/models

https://cloud.google.com/vertex-ai/docs/generative-ai/model-reference/overview

https://cloud.google.com/vertex-ai/docs/generative-ai/sdk-for-llm/llm-sdk-overview

https://cloud.google.com/vertex-ai/docs/generative-ai/multimodal/function-calling

https://spec.openapis.org/oas/v3.0.3#schema

